@@ -1,6 +1,3 @@
-from __future__ import print_function
-
-# no standard tests in this file, ignore
 __test__ = False
 
 if __name__ == '__main__':
