@@ -498,6 +498,18 @@ t2.join()
         self.assertEqual(lines[1], "True", lines[1])
 
 
+def test_patcher_existing_locks_early():
+    tests.run_isolated('patcher_existing_locks_early.py')
+
+
+def test_patcher_existing_locks_late():
+    tests.run_isolated('patcher_existing_locks_late.py')
+
+
+def test_patcher_existing_locks_locked():
+    tests.run_isolated('patcher_existing_locks_locked.py')
+
+
 def test_importlib_lock():
     tests.run_isolated('patcher_importlib_lock.py')
 
